@@ -1,33 +1,9 @@
 import re
 
-from json_resource import ResourceNotFound
+from json_resource import ResourceNotFound, Forbidden, UnAuthorized
 from flask import request, g
 
 
-class Forbidden(Exception):
-    """ Exception that is raised when an authorized request is disallowed.
-
-    Will return a 403 response.
-    """
-    pass
-
-
-class UnAuthorized(Exception):
-    """ Exception that is raised when a request is no authorized.
-
-    Will return a 401 response.
-    """
-    pass
-
-
-class ServiceUnavailable(Exception):
-    """ Exception that is raised when authorization service is not available.
-
-    Will return 503 response.
-    """
-    pass
-
-
 class Authorization(object):
     """ Authorization base object.
 
@@ -111,7 +87,7 @@ class TokenAuthorization(Authorization):
             g._flask_json_resource_token = \
                 self.token_class({'access_token': self.token_string}).load()
             return g._flask_json_resource_token
-        except Forbidden, e:
+        except ResourceNotFound:
             raise UnAuthorized('Invalid Access token')
 
     def check_authorization(self):
