@@ -7,10 +7,10 @@ from json_patch import Patch
 from . import response
 
 from json_patch import PatchError
-from json_resource import ResourceNotFound, ValidationError, ResourceExists
-from .authorization import (
-    UnAuthorized, Forbidden, ServiceUnavailable, Authorization
+from json_resource import (
+    ResourceNotFound, ValidationError, ResourceExists, UnAuthorized, Forbidden
 )
+from flask_json_resource.authorization import Authorization
 
 
 EXCEPTION_MAP = {
@@ -21,7 +21,6 @@ EXCEPTION_MAP = {
     ValueError: 400,
     UnAuthorized: 401,
     Forbidden: 403,
-    ServiceUnavailable: 503,
 }
 
 
@@ -195,7 +194,7 @@ class ResourceView(BaseView):
         """
         self.check_authorization()
 
-        resource = self.resource(kwargs)
+        resource = self.resource(kwargs).load()
         self.authorize(resource)
 
         resource.delete()
